import React from "react";
import { Typography, Link as MuiLink } from "@material-ui/core";

export default function GitRefLink({ deployment }) {
  let url = deployment?.sourceUrl;

  // if no git reference has been entered
  if (!url || url.trim === "") {
    return <></>;
  }

  // if user enters GIT url with '.git' postfix -> remove it
  if (url.toLowerCase().endsWith(".git")) {
    url = url.toLowerCase().split(".git")[0];
  }

  // add trailing '/' if needed for GIT server address
  if (!url.endsWith("/")) {
    url += "/";
  }

  // calculate the endpoint for tag/commitId
  url = url + "-/tree/" + deployment?.sourceVersion;

  return (
    <Typography display="inline">
      <MuiLink
        href={url}
        target="_blank"
        rel="noreferrer"
      >
        {deployment?.sourceVersionShort ?? deployment?.sourceVersion}
      </MuiLink>
    </Typography>
  );
}
