import React from "react";
import { Grid } from "@material-ui/core";
import { CustomTable } from "../common/table/CustomTable";
import { DeploymentStatusIcon } from "../deployments/DeploymentIcons";
import { CommandTypeIcon } from "./IOCIcons";
import { formatDate } from "../common/Helper";

const formatCommandDate = (value) => {
  if (value) {
    return formatDate(value);
  }
  return "Not started yet";
};

const dateTemplate = (rowData) => {
  return formatCommandDate(rowData.start);
};

const columns = [
  { id: "status", label: "Status", width: "10%", textAlign: "center" },
  { id: "type", label: "Command", width: "10%" },
  { id: "user", label: "User", width: "40%", sortable: false },
  {
    id: "start",
    label: "Timestamp",
    width: "40%",
    body: dateTemplate,
    sortable: false,
    textAlign: "center"
  }
];

function createTableRow(command) {
  return {
    id: command.id,
    type: (
      <Grid
        container
        direction="column"
        justifyContent="center"
        alignItems="center"
      >
        <CommandTypeIcon type={command.type} />
      </Grid>
    ),
    status: (
      <Grid
        container
        direction="column"
        justifyContent="center"
        alignItems="center"
      >
        <DeploymentStatusIcon status={command.status} />
      </Grid>
    ),
    user: command.createdBy,
    start: command.startDate
  };
}

export function IOCCommandTable({
  commands,
  commandLazyParams,
  setCommandLazyParams,
  commandColumnSort,
  setCommandColumnSort,
  rowsPerPage
}) {
  return (
    <CustomTable
      columns={columns}
      rows={commands.commandList.map((command) => createTableRow(command))}
      totalCount={commands.totalCount}
      lazyParams={commandLazyParams}
      setLazyParams={setCommandLazyParams}
      columnSort={commandColumnSort}
      setColumnSort={setCommandColumnSort}
      rowsPerPage={rowsPerPage}
    />
  );
}
